@@ -8,4 +8,4 @@ config = Config(".env")
 SECRET_KEY = config("SECRET_KEY", cast=Secret, default="SUPERSECRETKEYIFYOUKNOWWHATIMEAN")
 JWT_SUBJECT = 'access'
 ALGORITHM = 'HS256'
-USERS_URL = config("USERS_URL", cast=str, default="https:users.dev-bayestech.ru/public/v1/users")
\ No newline at end of file
+USERS_URL = config("USERS_URL", cast=str, default="https://users.dev-bayestech.ru/public/v1/users")
