@@ -6,9 +6,9 @@ from ..models.user import User
 from ..resources import strings
 
 
-async def get_user_from_token(token: str) -> User:
+def get_user_from_token(token: str) -> User:
     try:
-        return User(**jwt.decode(token, SECRET_KEY, algorithms=[ALGORITHM]).get("sub"))
+        return User(**jwt.decode(token, str(SECRET_KEY), algorithms=[ALGORITHM]).get("sub"))
     except jwt.PyJWTError as decode_error:
         raise ValueError(strings.UNABLE_JWT_TOKEN) from decode_error
     except ValidationError as validation_error:
